#line 1 "Sub/Quote.pm"
package Sub::Quote;

use strictures 1;

sub _clean_eval { eval $_[0] }

use Sub::Defer;
use Scalar::Util qw(weaken);
use base qw(Exporter);
use B ();
BEGIN {
  *_HAVE_PERLSTRING = defined &B::perlstring ? sub(){1} : sub(){0};
}

our $VERSION = '1.006000';
$VERSION = eval $VERSION;

our @EXPORT = qw(quote_sub unquote_sub quoted_from_sub qsub);
our @EXPORT_OK = qw(quotify capture_unroll inlinify);

our %QUOTED;

sub quotify {
  ! defined $_[0]     ? 'undef()'
  : _HAVE_PERLSTRING  ? B::perlstring($_[0])
  : qq["\Q$_[0]\E"];
}

sub capture_unroll {
  my ($from, $captures, $indent) = @_;
  join(
    '',
    map {
      /^([\@\%\$])/
        or die "capture key should start with \@, \% or \$: $_";
      (' ' x $indent).qq{my ${_} = ${1}{${from}->{${\quotify $_}}};\n};
    } keys %$captures
  );
}

sub inlinify {
  my ($code, $args, $extra, $local) = @_;
  my $do = 'do { '.($extra||'');
  if ($code =~ s/^(\s*package\s+([a-zA-Z0-9:]+);)//) {
    $do .= $1;
  }
  if ($code =~ s{(\A\s*|\A# BEGIN quote_sub PRELUDE\n.*?# END quote_sub PRELUDE\n\s*)(^\s*)(my\s*\(([^)]+)\)\s*=\s*\@_;)$}{
    my ($pre, $indent, $assign, $code_args) = ($1, $2, $3, $4);
    if ($code_args eq $args) {
      $pre . $indent . ($local ? 'local ' : '').'@_ = ('.$args.");\n"
      . $indent . $assign;
    }
    else {
      $pre . 'my ('.$code_args.') = ('.$args.'); ';
    }
  }mse) {
    #done
  }
  elsif ($local || $args ne '@_') {
    $do .= ($local ? 'local ' : '').'@_ = ('.$args.'); ';
  }
  $do.$code.' }';
}

sub quote_sub {
  # HOLY DWIMMERY, BATMAN!
  # $name => $code => \%captures => \%options
  # $name => $code => \%captures
  # $name => $code
  # $code => \%captures => \%options
  # $code
  my $options =
    (ref($_[-1]) eq 'HASH' and ref($_[-2]) eq 'HASH')
      ? pop
      : {};
  my $captures = ref($_[-1]) eq 'HASH' ? pop : undef;
  undef($captures) if $captures && !keys %$captures;
  my $code = pop;
  my $name = $_[0];
  my ($package, $hints, $bitmask, $hintshash) = (caller(0))[0,8,9,10];
  my $context
    ="# BEGIN quote_sub PRELUDE\n"
    ."package $package;\n"
    ."BEGIN {\n"
    ."  \$^H = ".quotify($hints).";\n"
    ."  \${^WARNING_BITS} = ".quotify($bitmask).";\n"
    ."  \%^H = (\n"
    . join('', map
     "    ".quotify($_)." => ".quotify($hintshash->{$_}).",",
      keys %$hintshash)
    ."  );\n"
    ."}\n"
    ."# END quote_sub PRELUDE\n";
  $code = "$context$code";
  my $quoted_info;
  my $unquoted;
  my $deferred = defer_sub +($options->{no_install} ? undef : $name) => sub {
    $unquoted if 0;
    unquote_sub($quoted_info->[4]);
  };
  $quoted_info = [ $name, $code, $captures, \$unquoted, $deferred ];
  weaken($quoted_info->[3]);
  weaken($quoted_info->[4]);
  weaken($QUOTED{$deferred} = $quoted_info);
  return $deferred;
}

sub quoted_from_sub {
  my ($sub) = @_;
  my $quoted_info = $QUOTED{$sub||''} or return undef;
  my ($name, $code, $captured, $unquoted, $deferred) = @{$quoted_info};
  $unquoted &&= $$unquoted;
  if (($deferred && $deferred eq $sub)
      || ($unquoted && $unquoted eq $sub)) {
    return [ $name, $code, $captured, $unquoted, $deferred ];
  }
  return undef;
}

sub unquote_sub {
  my ($sub) = @_;
  my $quoted = $QUOTED{$sub} or return undef;
  my $unquoted = $quoted->[3];
  unless ($unquoted && $$unquoted) {
    my ($name, $code, $captures) = @$quoted;

    my $make_sub = "{\n";

    my %captures = $captures ? %$captures : ();
    $captures{'$_UNQUOTED'} = \$unquoted;
    $captures{'$_QUOTED'} = \$quoted;
    $make_sub .= capture_unroll("\$_[1]", \%captures, 2);

    $make_sub .= (
      $name
          # disable the 'variable $x will not stay shared' warning since
          # we're not letting it escape from this scope anyway so there's
          # nothing trying to share it
        ? "  no warnings 'closure';\n  sub ${name} {\n"
        : "  \$\$_UNQUOTED = sub {\n"
    );
    $make_sub .= "  \$_QUOTED if 0;\n";
    $make_sub .= "  \$_UNQUOTED if 0;\n";
    $make_sub .= $code;
    $make_sub .= "  }".($name ? '' : ';')."\n";
    if ($name) {
      $make_sub .= "  \$\$_UNQUOTED = \\&${name}\n";
    }
    $make_sub .= "}\n1;\n";
    $ENV{SUB_QUOTE_DEBUG} && warn $make_sub;
    {
      no strict 'refs';
      local *{$name} if $name;
      my ($success, $e);
      {
        local $@;
        $success = _clean_eval($make_sub, \%captures);
        $e = $@;
      }
      unless ($success) {
        die "Eval went very, very wrong:\n\n${make_sub}\n\n$e";
      }
      weaken($QUOTED{$$unquoted} = $quoted);
    }
  }
  $$unquoted;
}

sub qsub ($) {
  goto &quote_sub;
}

sub CLONE {
  %QUOTED = map { defined $_ ? (
    $_->[3] && ${$_->[3]} ? (${ $_->[3] } => $_) : (),
    $_->[4] ? ($_->[4] => $_) : (),
  ) : () } values %QUOTED;
  weaken($_) for values %QUOTED;
}

1;
__END__

#line 369
